OnErrorStrategy

Enum OnErrorStrategy 

pub enum OnErrorStrategy {
    FailFast,
    Continue,
}
How the loop handles child node failures.

Variants



FailFast

Stop the loop on the first child failure (default).



Continue

Record the failure, skip the iteration, continue to the next.