OutputPersistence

Enum OutputPersistence 

pub enum OutputPersistence {
    Deferred,
    Progressive,
}
When loop iteration outputs are written to disk.

Variants



Deferred

Accumulate all outputs in memory, write after pipeline completes (default).



Progressive

Emit output files in events so consumers can write them immediately.