first_processing_node_id

Function first_processing_node_id 

pub fn first_processing_node_id(def: &PipelineDefinition) -> Option<String>
Walk the definition to find the first processing node (not I/O, not container). Used by the CLI to know where to inject params like URL.